aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorSilvio <silvio@devlet.com.br>2010-07-23 14:11:20 -0300
committerSilvio <silvio@devlet.com.br>2010-07-23 14:11:20 -0300
commitc33739f87ebf10e494f3c4d16ef4d53876f044f2 (patch)
treeb9118be218bf8e971933c7235a675afacd56e1e2 /tests
parent746f86a86cb03527ba1d4e695314d7654ecd0766 (diff)
downloadcinisis-c33739f87ebf10e494f3c4d16ef4d53876f044f2.tar.gz
cinisis-c33739f87ebf10e494f3c4d16ef4d53876f044f2.tar.bz2
Adding README and naming changes
Diffstat (limited to 'tests')
-rw-r--r--tests/csv.php8
-rw-r--r--tests/index.php6
-rw-r--r--tests/read.php6
3 files changed, 10 insertions, 10 deletions
diff --git a/tests/index.php b/tests/index.php
index 5a14f22..ebd465f 100644
--- a/tests/index.php
+++ b/tests/index.php
@@ -21,13 +21,13 @@ $isis = new CinisisDb();
// Test connection.
if ($isis->db) {
- $result = $isis->db->read(1);
- $rows = $isis->db->rows();
+ $result = $isis->db->read(1);
+ $entries = $isis->db->entries();
// Format output.
echo '<pre>';
echo "Connection test:\n";
- echo "Rows: $rows\n";
+ echo "Rows: $entries\n";
print_r($result);
echo '</pre>';
}
diff --git a/tests/read.php b/tests/read.php
index 2cb49ac..1235c25 100644
--- a/tests/read.php
+++ b/tests/read.php
@@ -35,14 +35,14 @@ foreach ($configs as $config) {
// Test connection.
if ($isis->db) {
- $result = $isis->db->read(1);
- $rows = $isis->db->rows();
+ $result = $isis->db->read(1);
+ $entries = $isis->db->entries();
// Format output.
echo '<td>';
echo '<pre>';
echo 'Implementation: '. $config['implementation'] ."\n";
- echo "Rows: $rows\n";
+ echo "Rows: $entries\n";
print_r($result);
echo '</pre>';
echo '</td>';
diff --git a/tests/csv.php b/tests/csv.php
index 57bb890..e50249b 100644
--- a/tests/csv.php
+++ b/tests/csv.php
@@ -60,9 +60,9 @@ $isis = new CinisisDb();
// Test connection.
if ($isis->db) {
- // Get format and number of rows.
- $rows = $isis->db->rows();
- $format = $isis->db->format;
+ // Get format and number of entries.
+ $entries = $isis->db->entries();
+ $format = $isis->db->format;
// Prepare output.
header("Content-type: application/text/x-csv");
@@ -84,7 +84,7 @@ if ($isis->db) {
echo "\n";
// Format output.
- for ($n = 1; $n <= $rows; $n++) {
+ for ($n = 1; $n <= $entries; $n++) {
$result = $isis->db->read($n);
if ($result) {